@@ -143,7 +143,7 @@ void LineEdit::_createEntry(void)
             break;
     }
 
-    connect(_entryWidget, SIGNAL(textChanged(QString)), SIGNAL(textChanged()));
+    connect(_entryWidget, SIGNAL(textChanged(QString)), SIGNAL(textChanged(QString)));
 
     if (_type == LineEdit::Long)
         connect(_entryWidget, SIGNAL(textChanged(QString)), SLOT(_updateCounter()));
@@ -254,7 +254,7 @@ void LineEdit::keyReleaseEvent(QKeyEvent *event)
     }
     update();
 
-    emit textChanged();
+    emit textChanged(_entryWidget->text());
 }
 
 /*!
