@@ -30,6 +30,7 @@
 #include <QtNetwork>
 
 #include "twitterapplicationitem.h"
+#include "imagedownload.h"
 #include "twitterapi/entry.h"
 
 class Tweet : public TwitterApplicationItem
@@ -59,8 +60,8 @@ signals:
     void selected(int);
 
 private slots:
-    void handleNetworkRequest(QNetworkReply *reply);
-    void download(QString Url);
+    void _imageReady(QString url);
+    void _download(QString url);
 
 private:
     void paint(QPainter *painter,const QStyleOptionGraphicsItem *option, QWidget *widget);
@@ -72,8 +73,7 @@ private:
 
 private:
     Entry m_entry;
-    QNetworkAccessManager m_manager;
-    QImage  m_image;
+    QImage  m_avatar;
     QGraphicsPixmapItem *m_rtImage;
     QGraphicsPixmapItem *m_favorited;
     bool    paintImage;
