@@ -43,13 +43,14 @@ public:
     enum ButtonType { Expose, Logout, Generic, Retweet, Reply, Refresh,
                       Favorite, NoFavorite, GoUrl, Delete, Back,
                       Close, More, LoginSettings, GenericDownLeft,
-                      GenericDownRight, NewAccount };
+                      GenericDownRight, NewAccount, Url };
 
     TwitterButton(ButtonType buttonType, QString buttonLabel, QGraphicsWidget *parent);
     QRectF boundingRect() const;
     void paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *);
     void setTypeButton(int);
     void setLabel(QString);
+    void setMessage(QString);
 
 signals:
     void pressed(void);
@@ -60,6 +61,7 @@ public slots:
 
 private slots:
     void _emitExposeSignal(void);
+    void _openUrl(void);
 
 protected:
     virtual void mousePressEvent(QGraphicsSceneMouseEvent *);
