@@ -28,6 +28,7 @@
 #include <QtNetwork>
 
 #include "twitterapplicationitem.h"
+#include "imagedownload.h"
 #include "twitterbutton.h"
 #include "kineticlist.h"
 #include "backend.h"
@@ -44,12 +45,11 @@ public:
     TwitterTopBar(QGraphicsWidget *parent);
 
 private slots:
-    void _handleNetworkRequest(QNetworkReply *reply);
+    void _imageReady(QString);
     void _download(QString url);
     void _positions(void);
 
 signals:
-    void finished(void);
     void changeAvatar(QString);
     void settings(void);
     void refresh(void);
@@ -64,7 +64,6 @@ private:
 private:
     QGraphicsTextItem *_name;
     QRectF *_rect;
-    QNetworkAccessManager m_manager;
     QList<QPointF> listPositions;
     QImage defaultAvatar;
     QImage m_avatar;
