@@ -31,16 +31,7 @@
   */
 namespace Timeline
 {
-    enum TimelineType { Users, Friends, Public };
-}
-
-/*! \namespace Connection Contains types of connections.
-  */
-namespace Connection
-{
-    enum ConnectionType { VerifyCredentials, Update, GetFriendsTimeline, RemoveStatus,
-                          AddFavorite, RemoveFavorite, addFriendship, RemoveFriendship,
-                          SendDirectMessage, };
+    enum TimelineType { Users, Friends, Public, Mentions };
 }
 
 /*!
@@ -53,7 +44,6 @@ class Backend : public QObject
 
     public:
         bool isLogin;
-        bool cancelNotPressed;
         static Backend *getInstance(void);
         void setFriendsPage(int page);
         void setUsersPage(int page);
@@ -67,6 +57,10 @@ class Backend : public QObject
         EntryList tweets(void);
         void abort(void);
 
+    private:
+        Backend(void);
+        void _addNewTweets(EntryList);
+
     public slots:
         void update(QString status, QString lat="", QString lon="", quint64 inReplyToStatusId=0);
         void getTimeline(Timeline::TimelineType type);
@@ -77,7 +71,6 @@ class Backend : public QObject
         void addFriendship(quint64 id);
         void sendDirectMessage(QString user, QString msg);
         bool updateProfileImage(QString image);
-        void getMentions(void);
 
     private slots:
         void _parseEntries(EntryList entries);
@@ -91,10 +84,10 @@ class Backend : public QObject
         void updateError(QString);
         void updatePosted(void);
         void gotFriendsTimeline(void);
+        void gotMentions(void);
         void deletedTweet(quint64);
 
     private:
-        Backend();
         static Backend *_instance;
         TwitterAPI *twitterapi;
         UserInfo userInformations;
@@ -103,6 +96,7 @@ class Backend : public QObject
         int userPage;
         EntryList _tweets;
         QList<int> conns;
+        QMap<int,Entry*> _tweetsMap;
 };
 
 #endif // BACKEND_H
