@@ -27,9 +27,9 @@
  */
 TimelineView::TimelineView(void) :
         timelineOnScreen(NULL),
-        leftPos(-801,0),
-        centerPos(0,0),
-        rightPos(801,0)
+        leftPos(-801,60),
+        centerPos(0,60),
+        rightPos(801,60)
 {
     _exitAnim = 0;
 }
@@ -186,7 +186,7 @@ void TimelineView::_createEntry()
  */
 void TimelineView::_createTweetInfo(Tweet *tweet)
 {
-    _tweetInfo = new TwitterTweetInfo(tweet, true, this);
+    _tweetInfo = new TwitterTweetInfo(tweet, this);
     _tweetInfo->setZValue(2.0);
     _tweetInfo->startAnimation();
 
@@ -195,7 +195,6 @@ void TimelineView::_createTweetInfo(Tweet *tweet)
     connect(_tweetInfo, SIGNAL(del(quint64, Tweet*)), this, SLOT(_emitDelete(quint64, Tweet*)));
 //    connect(_tweetInfo, SIGNAL(favorite(QString, bool)), this, SLOT(_emitFavorite(QString, bool)));
 //    connect(_tweetInfo, SIGNAL(unfollow(QString, bool)), this, SLOT(_emitUnfollow(QString, bool)));
-//    connect(_tweetInfo, SIGNAL(imageUrl(TwitPic::Services)), this, SLOT(_openTwitPic(TwitPic::Services)));
 //    connect(this, SIGNAL(loadMap()), _tweetInfo, SLOT(_loadMap()));
 }
 
@@ -315,13 +314,13 @@ void TimelineView::_moveToLeft(KineticList *oldTimeline, KineticList *newTimelin
 {
     QPropertyAnimation *anim1 = new QPropertyAnimation(oldTimeline,"pos");
     anim1->setStartValue(oldTimeline->pos());
-    anim1->setEndValue(oldTimeline->pos() + leftPos);
+    anim1->setEndValue(leftPos);
     anim1->setDuration(250);
     anim1->setEasingCurve(QEasingCurve::Linear);
 
     QPropertyAnimation *anim2 = new QPropertyAnimation(newTimeline,"pos");
     anim2->setStartValue(newTimeline->pos());
-    anim2->setEndValue(newTimeline->pos() + leftPos);
+    anim2->setEndValue(centerPos);
     anim2->setDuration(250);
     anim2->setEasingCurve(QEasingCurve::Linear);
 
@@ -335,13 +334,13 @@ void TimelineView::_moveToRight(KineticList *oldTimeline, KineticList *newTimeli
 {
     QPropertyAnimation *anim1 = new QPropertyAnimation(oldTimeline,"pos");
     anim1->setStartValue(oldTimeline->pos());
-    anim1->setEndValue(oldTimeline->pos() + rightPos);
+    anim1->setEndValue(rightPos);
     anim1->setDuration(250);
     anim1->setEasingCurve(QEasingCurve::Linear);
 
     QPropertyAnimation *anim2 = new QPropertyAnimation(newTimeline,"pos");
     anim2->setStartValue(newTimeline->pos());
-    anim2->setEndValue(newTimeline->pos() + rightPos);
+    anim2->setEndValue(centerPos);
     anim2->setDuration(250);
     anim2->setEasingCurve(QEasingCurve::Linear);
 
@@ -563,50 +562,6 @@ void TimelineView::_handleReply(QString newMessage, quint64 statusId)
     m_statusId = statusId;
 }
 
-void TimelineView::_openTwitPic(TwitPic::Services service)
-{
-//    m_twitPic = new TwitPic(this);
-//    connect(m_twitPic, SIGNAL(animExit()), this, SLOT(_closeTwitPic()));
-//    m_twitPic->setZValue(2.5);
-
-//    if(service == TwitPic::twitPic)
-//        m_twitPic->downloadTwitPic(_tweetInfo->getTwitPicUrl() + "/full");
-//    else
-//        if(service == TwitPic::tweetPhoto)
-//            m_twitPic->downloadTweetPhoto(_tweetInfo->getTweetPhotoUrl());
-
-//    QPropertyAnimation *animate = new QPropertyAnimation(m_twitPic, "scale");
-//    m_twitPic->setTransformOriginPoint(m_twitPic->boundingRect().center());
-//    animate->setStartValue(0);
-//    animate->setEndValue(1);
-//    animate->setDuration(700);
-//    animate->setEasingCurve(QEasingCurve::OutExpo);
-//    animate->start(QPropertyAnimation::DeleteWhenStopped);
-}
-
-void TimelineView::_closeTwitPic()
-{
-//    QPropertyAnimation *animate = new QPropertyAnimation(m_twitPic, "scale");
-//    m_twitPic->setTransformOriginPoint(m_twitPic->boundingRect().center());
-//    animate->setStartValue(1);
-//    animate->setEndValue(0);
-//    animate->setDuration(700);
-//    animate->setEasingCurve(QEasingCurve::OutExpo);
-//    animate->start(QPropertyAnimation::DeleteWhenStopped);
-
-//    connect(animate, SIGNAL(finished()), this, SLOT(_deleteTwitPic()));
-}
-
-void TimelineView::_deleteTwitPic()
-{
-//    delete m_twitPic;
-}
-
-bool TimelineView::getHome(void)
-{
-//    return this->m_home;
-}
-
 void TimelineView::addMoreButton(Timeline::TimelineType type)
 {
     switch(type)
