@@ -34,7 +34,6 @@
 #include "applicationItems/timelinesettings.h"
 #include "urlshortener.h"
 #include "location/getiplocation.h"
-#include "twitpic.h"
 
 #ifdef Q_WS_MAEMO_5
     #include <QMaemo5InformationBox>
@@ -56,7 +55,6 @@ public:
     void setUpdateMessage(const QString &message);
     void updateTopBar(void);
     QString getUpdateMessage(void);
-    bool getHome(void);
     void addMoreButton(Timeline::TimelineType);
     void tweetDeleted(quint64);
     void clearText(void);
@@ -105,9 +103,6 @@ private slots:
     void _toHome(void);
     void _toMentions(void);
     void _showIpLocationInfo(double latitude, double longitude);
-    void _openTwitPic(TwitPic::Services);
-    void _closeTwitPic(void);
-    void _deleteTwitPic(void);
 
 private:
     QAbstractAnimation *_createEntryAnimation(void);
@@ -152,7 +147,6 @@ public:
     KineticList *_homeTimeline;
     KineticList *_mentionsTimeline;
     TimelineSettings *_settingsDialog;
-    TwitPic *m_twitPic;
 
     bool isReply;
 
