@@ -25,7 +25,6 @@
 
 #include <QNetworkAccessManager>
 #include <QNetworkRequest>
-#include <QNetworkReply>
 #include <QXmlSimpleReader>
 #include <QXmlInputSource>
 #include <QAuthenticator>
@@ -268,8 +267,10 @@ TwitterAPI::TwitterAPI( const QString &serviceUrl, const QString &login,
     Q_D(TwitterAPI);
 
     d->q_ptr = this;
-
     d->init( serviceUrl, login, password, usingOAuth );
+
+    netReply = NULL;
+    connect(netReply, SIGNAL(error(QNetworkReply::NetworkError)), SIGNAL(errorMessage(QNetworkReply::NetworkError)));
 }
 #else
 TwitterAPI::TwitterAPI( const QString &serviceUrl, const QString &login,
